## Colorchef v0.0.5
**This package lets you print colored text on the terminal.**        
Author : Mithilesh Pradhan

### Usage   

```
import colorchef        
print(colorchef.COLORCHEF.Blue,"Hello from colorchef",colorchef.COLORCHEF.ResetAll)
```

- Alternative way    
```
from colorchef import COLORCHEF    
(COLORCHEF.Blue,"Hello from colorchef",COLORCHEF.ResetAll)
```


***
#### List of attributes available:   

BackgroundBlack 
BackgroundBlue
BackgroundCyan 
BackgroundDarkGray 
BackgroundDefault 
BackgroundGreen 
BackgroundLightBlue 
BackgroundLightCyan 
BackgroundLightGray 
BackgroundLightGreen
BackgroundLightMagenta 
BackgroundLightRed 
BackgroundLightYellow 
BackgroundMagenta 
BackgroundRed 
BackgroundWhite 
BackgroundYellow 
Black 
Blink 
Blue 
Bold 
Cyan 
DarkGray 
Default 
Dim 
Green 
Hidden
LightBlue 
LightCyan 
LightGray
LightGreen
LightMagenta
LightRed 
LightYellow
Magenta
Red
ResetAll
ResetBlink
ResetBold
ResetDim
ResetHidden
ResetReverse
ResetUnderlined
Reverse
Underlined
White
Yellow       








***Thanks for the support!!***
Follow me on LinkedIn below  
[Mithilesh Pradhan - Linkedin](https://linkedin.com/in/mithileshpradhan/ "Mithilesh Pradhan - Linkedin")   
 


